@@ -742,8 +742,8 @@ class TestSnapQuirks(unittest.TestCase):
         controller = mock.Mock()
         config = mock.Mock()
         q = DistUpgradeQuirks(controller, config)
-        q._from_version = "19.04"
-        q._to_version = "19.10"
+        q._from_version = "20.04"
+        q._to_version = "22.04"
         # Call method under test
 
         controller.cache = {
@@ -755,10 +755,6 @@ class TestSnapQuirks(unittest.TestCase):
                 make_mock_pkg(
                     name="core18",
                     is_installed=True),
-            'firefox':
-                make_mock_pkg(
-                    name="firefox",
-                    is_installed=True),
             'gnome-3-28-1804':
                 make_mock_pkg(
                     name="gnome-3-28-1804",
@@ -799,23 +795,12 @@ class TestSnapQuirks(unittest.TestCase):
                 'channel': 'stable',
                 'command': 'install',
                 'deb': None, 'snap-id': '1234'},
-             'firefox': {
-                'channel': 'stable/ubuntu-19.10',
-                'command': 'install',
-                'deb': 'firefox',
-                'snap-id': '1234'},
-             'gnome-3-34-1804': {
-                'channel': 'stable/ubuntu-19.10',
-                'command': 'install',
-                'deb': None, 'snap-id': '1234'},
              'gnome-3-38-2004': {
-                'channel': 'stable/ubuntu-19.10',
+                'channel': 'stable/ubuntu-22.04',
                 'command': 'install',
                 'deb': None, 'snap-id': '1234'},
-             'gnome-logs': {
-                'command': 'remove'},
              'snap-store': {
-                'channel': 'stable/ubuntu-19.10',
+                'channel': 'stable/ubuntu-22.04',
                 'command': 'install',
                 'deb': 'gnome-software',
                 'snap-id': '1234'}})
